Rekisteröinti | OiRA

Aiheet

# Rekisteröinti

## Miksi rekisteröinti on tarpeen?

Ennen ensimmäisen riskinarvioinnin aloittamista sinua pyydetään luomaan OiRA-tili - se käy helposti ja nopeasti.

Kun olet rekisteröitynyt, voit kirjautua järjestelmään milloin tahansa, tarkastella tietojasi, jatkaa edellisten arviointien tekemistä tai aloittaa uusia.

Rekisteröinti tarkoittaa, että OiRA-järjestelmä voi tallentaa kaikki istuntosi ja että tietosi ovat aina saatavilla.

Tutustu tietosuojakäytäntöömme ja siihen, miten henkilötietoja käsitellään.

## Mitä eroa on käyttäjäksi rekisteröitymisellä ja kokeiluversion testaamisella?

Kokeiluversiossa asiasta kiinnostuneet voivat tutustua työkaluun ennen rekisteröitymistä. Kokeiluversiossa tietoja ei kuitenkaan tallenneta eikä annettuja tietoja pysty hakemaan myöhemmin. Kokeiluversiossa raportteja ei voi tulostaa. Rekisteröidyltä tililtä riskinarviointidokumentaatio on kuitenkin käytettävissä kokonaisuudessaan.

## Uuden tilin rekisteröinti

Onko tämä ensimmäinen käyntisi? Toimi seuraavasti:

1.) Saat rekisteröintilomakkeen näkyviin napsauttamalla ”Rekisteröidy käyttäjäksi”.

Rekisteröintilomake

2.) Kirjoita sähköpostiosoitteesi ja salasana (kahdesti)

3.) Rekisteröi uusi tilisi napsauttamalla ”Seuraava”.

4.) Jatka lukemalla ja hyväksymällä tietosuojaseloste

Seuraavaksi sinut kirjataan sisään OiRA-järjestelmään.

## Kirjautuminen olemassa olevalle tilille

Jos olet rekisteröitynyt aiemmin, pääset tilillesi seuraavasti:

1.) Siirry kirjautumissivulle. Linkki kirjautumissivulle tulee näkyviin aina, kun yrität päästä OiRA-järjestelmään, kunnes kirjaudut sisään.

Kirjautumislomake

2.) Syötä sähköpostiosoitteesi ja salasanasi.

3.) Kirjaudu sisään napsauttamalla painiketta ”Sisäänkirjautuminen”.

Kun olet kirjautunut sisään, näkyviin tulee seuraava näyttö. Tästä voit aloittaa uuden riskinarvioinnin tai palata aiemmin aloittamiisi riskinarviointeihin.

Koontinäyttö

Aloita uusi riskinarviointi antamalla sille nimi (esim. Oma-yritys 2018-07-03) tai avaa jokin aiemmista riskinarvioinneistasi. Kaikki aloittamasi riskinarvioinnit tallennetaan myöhempää käyttöä varten, ellet poista niitä.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More